"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .jobresponse import JobResponse, JobResponseTypedDict
from .paginationdetails import PaginationDetails, PaginationDetailsTypedDict
from flowai_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class JobListResponseTypedDict(TypedDict):
    jobs: List[JobResponseTypedDict]
    pagination: PaginationDetailsTypedDict


class JobListResponse(BaseModel):
    jobs: List[JobResponse]

    pagination: PaginationDetails



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .jwtpayload import JWTPayload, JWTPayloadTypedDict
from .testcaseupdate import TestCaseUpdate, TestCaseUpdateTypedDict
from flowai_sdk.types import BaseModel
from typing_extensions import TypedDict


class BodyUpdateTestCaseTestCasesTestCaseIDPutTypedDict(TypedDict):
    test_case_in: TestCaseUpdateTypedDict
    r"""Schema for updating a test case (all fields optional)"""
    current_user_payload: JWTPayloadTypedDict
    r"""Schema representing the essential parts of a JWT payload for user identification."""


class BodyUpdateTestCaseTestCasesTestCaseIDPut(BaseModel):
    test_case_in: TestCaseUpdate
    r"""Schema for updating a test case (all fields optional)"""

    current_user_payload: JWTPayload
    r"""Schema representing the essential parts of a JWT payload for user identification."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from flowai_sdk import errors, models, utils
from flowai_sdk._hooks import HookContext
from flowai_sdk.types import OptionalNullable, UNSET
from typing import Any, List, Mapping, Optional, Union


class TestCases(BaseSDK):
    def list(
        self,
        *,
        sub: str,
        skip: Optional[int] = 0,
        limit: Optional[int] = 100,
        sort_by: OptionalNullable[str] = UNSET,
        sort_order: Optional[str] = "asc",
        name: OptionalNullable[str] = UNSET,
        status: OptionalNullable[str] = UNSET,
        created_after: OptionalNullable[str] = UNSET,
        created_before: OptionalNullable[str] = UNSET,
        batch_id: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> List[models.TestCaseRead]:
        r"""List Test Cases

        :param sub:
        :param skip:
        :param limit:
        :param sort_by: Field to sort by (e.g., 'name', 'created_at')
        :param sort_order: Sort direction ('asc' or 'desc')
        :param name: Filter by name (partial match)
        :param status: Filter by status
        :param created_after: Filter by creation date (ISO format, YYYY-MM-DDTHH:MM:SSZ)
        :param created_before: Filter by creation date (ISO format, YYYY-MM-DDTHH:MM:SSZ)
        :param batch_id: Filter by Batch ID
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.ListTestCasesTestCasesGetRequest(
            skip=skip,
            limit=limit,
            sort_by=sort_by,
            sort_order=sort_order,
            name=name,
            status=status,
            created_after=created_after,
            created_before=created_before,
            batch_id=batch_id,
            jwt_payload=models.JWTPayload(
                sub=sub,
            ),
        )

        req = self._build_request(
            method="GET",
            path="/test-cases/",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.jwt_payload, False, False, "json", models.JWTPayload
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="list_test_cases_test_cases__get",
                oauth2_scopes=[],
                security_source=None,
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, List[models.TestCaseRead])
        if utils.match_response(http_res, "422", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, errors.HTTPValidationErrorData
            )
            raise errors.HTTPValidationError(data=response_data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise errors.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def list_async(
        self,
        *,
        sub: str,
        skip: Optional[int] = 0,
        limit: Optional[int] = 100,
        sort_by: OptionalNullable[str] = UNSET,
        sort_order: Optional[str] = "asc",
        name: OptionalNullable[str] = UNSET,
        status: OptionalNullable[str] = UNSET,
        created_after: OptionalNullable[str] = UNSET,
        created_before: OptionalNullable[str] = UNSET,
        batch_id: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> List[models.TestCaseRead]:
        r"""List Test Cases

        :param sub:
        :param skip:
        :param limit:
        :param sort_by: Field to sort by (e.g., 'name', 'created_at')
        :param sort_order: Sort direction ('asc' or 'desc')
        :param name: Filter by name (partial match)
        :param status: Filter by status
        :param created_after: Filter by creation date (ISO format, YYYY-MM-DDTHH:MM:SSZ)
        :param created_before: Filter by creation date (ISO format, YYYY-MM-DDTHH:MM:SSZ)
        :param batch_id: Filter by Batch ID
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.ListTestCasesTestCasesGetRequest(
            skip=skip,
            limit=limit,
            sort_by=sort_by,
            sort_order=sort_order,
            name=name,
            status=status,
            created_after=created_after,
            created_before=created_before,
            batch_id=batch_id,
            jwt_payload=models.JWTPayload(
                sub=sub,
            ),
        )

        req = self._build_request_async(
            method="GET",
            path="/test-cases/",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.jwt_payload, False, False, "json", models.JWTPayload
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="list_test_cases_test_cases__get",
                oauth2_scopes=[],
                security_source=None,
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, List[models.TestCaseRead])
        if utils.match_response(http_res, "422", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, errors.HTTPValidationErrorData
            )
            raise errors.HTTPValidationError(data=response_data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise errors.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    def create(
        self,
        *,
        expected_output: str,
        status: str,
        api_key_user_id: Optional[str] = "mock_api_key_user_id",
        name: OptionalNullable[str] = UNSET,
        description: OptionalNullable[str] = UNSET,
        is_active: Optional[bool] = True,
        trajectory: Optional[
            Union[List[models.Trajectory], List[models.TrajectoryTypedDict]]
        ] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.TestCaseRead:
        r"""Create Test Case

        :param expected_output:
        :param status:
        :param api_key_user_id:
        :param name:
        :param description:
        :param is_active:
        :param trajectory:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.CreateTestCaseTestCasesPostRequest(
            api_key_user_id=api_key_user_id,
            test_case_create=models.TestCaseCreate(
                name=name,
                description=description,
                expected_output=expected_output,
                status=status,
                is_active=is_active,
                trajectory=utils.get_pydantic_model(
                    trajectory, Optional[List[models.Trajectory]]
                ),
            ),
        )

        req = self._build_request(
            method="POST",
            path="/test-cases/",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.test_case_create, False, False, "json", models.TestCaseCreate
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="create_test_case_test_cases__post",
                oauth2_scopes=[],
                security_source=None,
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "201", "application/json"):
            return utils.unmarshal_json(http_res.text, models.TestCaseRead)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, errors.HTTPValidationErrorData
            )
            raise errors.HTTPValidationError(data=response_data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise errors.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def create_async(
        self,
        *,
        expected_output: str,
        status: str,
        api_key_user_id: Optional[str] = "mock_api_key_user_id",
        name: OptionalNullable[str] = UNSET,
        description: OptionalNullable[str] = UNSET,
        is_active: Optional[bool] = True,
        trajectory: Optional[
            Union[List[models.Trajectory], List[models.TrajectoryTypedDict]]
        ] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.TestCaseRead:
        r"""Create Test Case

        :param expected_output:
        :param status:
        :param api_key_user_id:
        :param name:
        :param description:
        :param is_active:
        :param trajectory:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.CreateTestCaseTestCasesPostRequest(
            api_key_user_id=api_key_user_id,
            test_case_create=models.TestCaseCreate(
                name=name,
                description=description,
                expected_output=expected_output,
                status=status,
                is_active=is_active,
                trajectory=utils.get_pydantic_model(
                    trajectory, Optional[List[models.Trajectory]]
                ),
            ),
        )

        req = self._build_request_async(
            method="POST",
            path="/test-cases/",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.test_case_create, False, False, "json", models.TestCaseCreate
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="create_test_case_test_cases__post",
                oauth2_scopes=[],
                security_source=None,
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "201", "application/json"):
            return utils.unmarshal_json(http_res.text, models.TestCaseRead)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, errors.HTTPValidationErrorData
            )
            raise errors.HTTPValidationError(data=response_data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise errors.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    def get(
        self,
        *,
        test_case_id: str,
        sub: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.TestCaseRead:
        r"""Get Test Case

        :param test_case_id:
        :param sub:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetTestCaseTestCasesTestCaseIDGetRequest(
            test_case_id=test_case_id,
            jwt_payload=models.JWTPayload(
                sub=sub,
            ),
        )

        req = self._build_request(
            method="GET",
            path="/test-cases/{test_case_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=False,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.jwt_payload, False, False, "json", models.JWTPayload
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="get_test_case_test_cases__test_case_id__get",
                oauth2_scopes=[],
                security_source=None,
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.TestCaseRead)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, errors.HTTPValidationErrorData
            )
            raise errors.HTTPValidationError(data=response_data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise errors.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def get_async(
        self,
        *,
        test_case_id: str,
        sub: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.TestCaseRead:
        r"""Get Test Case

        :param test_case_id:
        :param sub:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetTestCaseTestCasesTestCaseIDGetRequest(
            test_case_id=test_case_id,
            jwt_payload=models.JWTPayload(
                sub=sub,
            ),
        )

        req = self._build_request_async(
            method="GET",
            path="/test-cases/{test_case_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=False,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.jwt_payload, False, False, "json", models.JWTPayload
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="get_test_case_test_cases__test_case_id__get",
                oauth2_scopes=[],
                security_source=None,
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.TestCaseRead)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, errors.HTTPValidationErrorData
            )
            raise errors.HTTPValidationError(data=response_data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise errors.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    def update(
        self,
        *,
        test_case_id: str,
        test_case_in: Union[models.TestCaseUpdate, models.TestCaseUpdateTypedDict],
        current_user_payload: Union[models.JWTPayload, models.JWTPayloadTypedDict],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.TestCaseRead:
        r"""Update Test Case

        :param test_case_id:
        :param test_case_in: Schema for updating a test case (all fields optional)
        :param current_user_payload: Schema representing the essential parts of a JWT payload for user identification.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.UpdateTestCaseTestCasesTestCaseIDPutRequest(
            test_case_id=test_case_id,
            body_update_test_case_test_cases_test_case_id_put=models.BodyUpdateTestCaseTestCasesTestCaseIDPut(
                test_case_in=utils.get_pydantic_model(
                    test_case_in, models.TestCaseUpdate
                ),
                current_user_payload=utils.get_pydantic_model(
                    current_user_payload, models.JWTPayload
                ),
            ),
        )

        req = self._build_request(
            method="PUT",
            path="/test-cases/{test_case_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=False,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.body_update_test_case_test_cases_test_case_id_put,
                False,
                False,
                "json",
                models.BodyUpdateTestCaseTestCasesTestCaseIDPut,
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="update_test_case_test_cases__test_case_id__put",
                oauth2_scopes=[],
                security_source=None,
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.TestCaseRead)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, errors.HTTPValidationErrorData
            )
            raise errors.HTTPValidationError(data=response_data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise errors.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def update_async(
        self,
        *,
        test_case_id: str,
        test_case_in: Union[models.TestCaseUpdate, models.TestCaseUpdateTypedDict],
        current_user_payload: Union[models.JWTPayload, models.JWTPayloadTypedDict],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.TestCaseRead:
        r"""Update Test Case

        :param test_case_id:
        :param test_case_in: Schema for updating a test case (all fields optional)
        :param current_user_payload: Schema representing the essential parts of a JWT payload for user identification.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.UpdateTestCaseTestCasesTestCaseIDPutRequest(
            test_case_id=test_case_id,
            body_update_test_case_test_cases_test_case_id_put=models.BodyUpdateTestCaseTestCasesTestCaseIDPut(
                test_case_in=utils.get_pydantic_model(
                    test_case_in, models.TestCaseUpdate
                ),
                current_user_payload=utils.get_pydantic_model(
                    current_user_payload, models.JWTPayload
                ),
            ),
        )

        req = self._build_request_async(
            method="PUT",
            path="/test-cases/{test_case_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=False,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.body_update_test_case_test_cases_test_case_id_put,
                False,
                False,
                "json",
                models.BodyUpdateTestCaseTestCasesTestCaseIDPut,
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="update_test_case_test_cases__test_case_id__put",
                oauth2_scopes=[],
                security_source=None,
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.TestCaseRead)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, errors.HTTPValidationErrorData
            )
            raise errors.HTTPValidationError(data=response_data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise errors.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    def delete(
        self,
        *,
        test_case_id: str,
        sub: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ):
        r"""Delete Test Case

        :param test_case_id:
        :param sub:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.DeleteTestCaseTestCasesTestCaseIDDeleteRequest(
            test_case_id=test_case_id,
            jwt_payload=models.JWTPayload(
                sub=sub,
            ),
        )

        req = self._build_request(
            method="DELETE",
            path="/test-cases/{test_case_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=False,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.jwt_payload, False, False, "json", models.JWTPayload
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="delete_test_case_test_cases__test_case_id__delete",
                oauth2_scopes=[],
                security_source=None,
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "204", "*"):
            return
        if utils.match_response(http_res, "422", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, errors.HTTPValidationErrorData
            )
            raise errors.HTTPValidationError(data=response_data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise errors.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def delete_async(
        self,
        *,
        test_case_id: str,
        sub: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ):
        r"""Delete Test Case

        :param test_case_id:
        :param sub:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.DeleteTestCaseTestCasesTestCaseIDDeleteRequest(
            test_case_id=test_case_id,
            jwt_payload=models.JWTPayload(
                sub=sub,
            ),
        )

        req = self._build_request_async(
            method="DELETE",
            path="/test-cases/{test_case_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=False,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.jwt_payload, False, False, "json", models.JWTPayload
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="delete_test_case_test_cases__test_case_id__delete",
                oauth2_scopes=[],
                security_source=None,
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "204", "*"):
            return
        if utils.match_response(http_res, "422", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, errors.HTTPValidationErrorData
            )
            raise errors.HTTPValidationError(data=response_data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise errors.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    def get_validation(
        self,
        *,
        test_case_id: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> Any:
        r"""Get Single Validation From Batch

        :param test_case_id:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = (
            models.GetSingleValidationFromBatchTestCasesTestCaseIDValidationGetRequest(
                test_case_id=test_case_id,
            )
        )

        req = self._build_request(
            method="GET",
            path="/test-cases/{test_case_id}/validation",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=False,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="get_single_validation_from_batch_test_cases__test_case_id__validation_get",
                oauth2_scopes=[],
                security_source=None,
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, Any)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, errors.HTTPValidationErrorData
            )
            raise errors.HTTPValidationError(data=response_data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise errors.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def get_validation_async(
        self,
        *,
        test_case_id: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> Any:
        r"""Get Single Validation From Batch

        :param test_case_id:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = (
            models.GetSingleValidationFromBatchTestCasesTestCaseIDValidationGetRequest(
                test_case_id=test_case_id,
            )
        )

        req = self._build_request_async(
            method="GET",
            path="/test-cases/{test_case_id}/validation",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=False,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="get_single_validation_from_batch_test_cases__test_case_id__validation_get",
                oauth2_scopes=[],
                security_source=None,
            ),
            request=req,
            error_status_codes=["422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, Any)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, errors.HTTPValidationErrorData
            )
            raise errors.HTTPValidationError(data=response_data)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise errors.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from typing import TYPE_CHECKING
from importlib import import_module

if TYPE_CHECKING:
    from .add_project_validator_projects_project_id_validators_postop import (
        AddProjectValidatorProjectsProjectIDValidatorsPostRequest,
        AddProjectValidatorProjectsProjectIDValidatorsPostRequestTypedDict,
    )
    from .apikeycreate import APIKeyCreate, APIKeyCreateTypedDict
    from .apikeycreateresponse import (
        APIKeyCreateResponse,
        APIKeyCreateResponseTypedDict,
    )
    from .apikeyinfo import APIKeyInfo, APIKeyInfoTypedDict
    from .apikeyupdate import APIKeyUpdate, APIKeyUpdateTypedDict
    from .archive_project_projects_project_id_archive_postop import (
        ArchiveProjectProjectsProjectIDArchivePostRequest,
        ArchiveProjectProjectsProjectIDArchivePostRequestTypedDict,
    )
    from .batchread import BatchRead, BatchReadTypedDict
    from .batchstatusread import BatchStatusRead, BatchStatusReadTypedDict
    from .body_create_stages_for_project_stages_post import (
        BodyCreateStagesForProjectStagesPost,
        BodyCreateStagesForProjectStagesPostTypedDict,
        File,
        FileTypedDict,
    )
    from .body_update_test_case_test_cases_test_case_id_put import (
        BodyUpdateTestCaseTestCasesTestCaseIDPut,
        BodyUpdateTestCaseTestCasesTestCaseIDPutTypedDict,
    )
    from .cancel_job_by_id_jobs_job_id_cancel_postop import (
        CancelJobByIDJobsJobIDCancelPostRequest,
        CancelJobByIDJobsJobIDCancelPostRequestTypedDict,
    )
    from .check_validation_task_status_validation_tasks_validation_task_id_getop import (
        CheckValidationTaskStatusValidationTasksValidationTaskIDGetRequest,
        CheckValidationTaskStatusValidationTasksValidationTaskIDGetRequestTypedDict,
    )
    from .create_job_for_project_projects_project_id_jobs_postop import (
        CreateJobForProjectProjectsProjectIDJobsPostRequest,
        CreateJobForProjectProjectsProjectIDJobsPostRequestTypedDict,
    )
    from .create_test_case_test_cases_postop import (
        CreateTestCaseTestCasesPostRequest,
        CreateTestCaseTestCasesPostRequestTypedDict,
    )
    from .create_test_case_validation_validations_postop import (
        CreateTestCaseValidationValidationsPostRequest,
        CreateTestCaseValidationValidationsPostRequestTypedDict,
    )
    from .create_validation_task_for_batch_endpoint_batches_batch_id_validation_tasks_postop import (
        CreateValidationTaskForBatchEndpointBatchesBatchIDValidationTasksPostRequest,
        CreateValidationTaskForBatchEndpointBatchesBatchIDValidationTasksPostRequestTypedDict,
    )
    from .createvalidationtaskresponse import (
        CreateValidationTaskResponse,
        CreateValidationTaskResponseTypedDict,
    )
    from .datasetgenerationrequest import (
        DatasetGenerationRequest,
        DatasetGenerationRequestTypedDict,
    )
    from .datasetitemlistresponse import (
        DatasetItemListResponse,
        DatasetItemListResponseTypedDict,
    )
    from .datasetitemread import DatasetItemRead, DatasetItemReadTypedDict
    from .datasetread import DatasetRead, DatasetReadTypedDict
    from .delete_batch_by_id_batches_batch_id_deleteop import (
        DeleteBatchByIDBatchesBatchIDDeleteRequest,
        DeleteBatchByIDBatchesBatchIDDeleteRequestTypedDict,
    )
    from .delete_dataset_datasets_dataset_id_deleteop import (
        DeleteDatasetDatasetsDatasetIDDeleteRequest,
        DeleteDatasetDatasetsDatasetIDDeleteRequestTypedDict,
    )
    from .delete_project_projects_project_id_deleteop import (
        DeleteProjectProjectsProjectIDDeleteRequest,
        DeleteProjectProjectsProjectIDDeleteRequestTypedDict,
    )
    from .delete_stage_stages_stage_id_deleteop import (
        DeleteStageStagesStageIDDeleteRequest,
        DeleteStageStagesStageIDDeleteRequestTypedDict,
    )
    from .delete_test_case_test_cases_test_case_id_deleteop import (
        DeleteTestCaseTestCasesTestCaseIDDeleteRequest,
        DeleteTestCaseTestCasesTestCaseIDDeleteRequestTypedDict,
    )
    from .delete_validation_validations_validation_id_deleteop import (
        DeleteValidationValidationsValidationIDDeleteRequest,
        DeleteValidationValidationsValidationIDDeleteRequestTypedDict,
    )
    from .edit_test_case_validation_validator_tasks_validator_task_id_validations_validation_id_putop import (
        EditTestCaseValidationValidatorTasksValidatorTaskIDValidationsValidationIDPutRequest,
        EditTestCaseValidationValidatorTasksValidatorTaskIDValidationsValidationIDPutRequestTypedDict,
    )
    from .generate_batch_for_job_jobs_job_id_generate_batch_postop import (
        GenerateBatchForJobJobsJobIDGenerateBatchPostRequest,
        GenerateBatchForJobJobsJobIDGenerateBatchPostRequestTypedDict,
    )
    from .generate_dataset_for_job_jobs_job_id_generate_dataset_postop import (
        GenerateDatasetForJobJobsJobIDGenerateDatasetPostRequest,
        GenerateDatasetForJobJobsJobIDGenerateDatasetPostRequestTypedDict,
    )
    from .get_batch_by_id_batches_batch_id_getop import (
        GetBatchByIDBatchesBatchIDGetRequest,
        GetBatchByIDBatchesBatchIDGetRequestTypedDict,
    )
    from .get_batch_status_endpoint_batches_batch_id_status_getop import (
        GetBatchStatusEndpointBatchesBatchIDStatusGetRequest,
        GetBatchStatusEndpointBatchesBatchIDStatusGetRequestTypedDict,
    )
    from .get_batch_test_cases_batches_batch_id_testcases_getop import (
        GetBatchTestCasesBatchesBatchIDTestcasesGetRequest,
        GetBatchTestCasesBatchesBatchIDTestcasesGetRequestTypedDict,
    )
    from .get_dataset_items_datasets_dataset_id_items_getop import (
        GetDatasetItemsDatasetsDatasetIDItemsGetRequest,
        GetDatasetItemsDatasetsDatasetIDItemsGetRequestTypedDict,
    )
    from .get_job_details_jobs_job_id_getop import (
        GetJobDetailsJobsJobIDGetRequest,
        GetJobDetailsJobsJobIDGetRequestTypedDict,
    )
    from .get_project_dataset_projects_project_id_dataset_getop import (
        GetProjectDatasetProjectsProjectIDDatasetGetRequest,
        GetProjectDatasetProjectsProjectIDDatasetGetRequestTypedDict,
    )
    from .get_project_projects_project_id_getop import (
        GetProjectProjectsProjectIDGetRequest,
        GetProjectProjectsProjectIDGetRequestTypedDict,
    )
    from .get_single_validation_from_batch_test_cases_test_case_id_validation_getop import (
        GetSingleValidationFromBatchTestCasesTestCaseIDValidationGetRequest,
        GetSingleValidationFromBatchTestCasesTestCaseIDValidationGetRequestTypedDict,
    )
    from .get_stage_details_stages_stage_id_getop import (
        GetStageDetailsStagesStageIDGetRequest,
        GetStageDetailsStagesStageIDGetRequestTypedDict,
    )
    from .get_test_case_test_cases_test_case_id_getop import (
        GetTestCaseTestCasesTestCaseIDGetRequest,
        GetTestCaseTestCasesTestCaseIDGetRequestTypedDict,
    )
    from .get_validation_task_for_batch_endpoint_batches_batch_id_validation_task_getop import (
        GetValidationTaskForBatchEndpointBatchesBatchIDValidationTaskGetRequest,
        GetValidationTaskForBatchEndpointBatchesBatchIDValidationTaskGetRequestTypedDict,
    )
    from .get_validation_validations_validation_id_getop import (
        GetValidationValidationsValidationIDGetRequest,
        GetValidationValidationsValidationIDGetRequestTypedDict,
    )
    from .get_validations_for_batch_batches_batch_id_validations_getop import (
        GetValidationsForBatchBatchesBatchIDValidationsGetRequest,
        GetValidationsForBatchBatchesBatchIDValidationsGetRequestTypedDict,
    )
    from .getvalidationtaskforbatchresponseschema import (
        GetValidationTaskForBatchResponseSchema,
        GetValidationTaskForBatchResponseSchemaTypedDict,
    )
    from .handle_clerk_webhook_endpoint_clerk_webhooks_postop import (
        HandleClerkWebhookEndpointClerkWebhooksPostRequest,
        HandleClerkWebhookEndpointClerkWebhooksPostRequestTypedDict,
    )
    from .jobbatchgenerationresponse import (
        JobBatchGenerationResponse,
        JobBatchGenerationResponseTypedDict,
    )
    from .jobcancelresponse import JobCancelResponse, JobCancelResponseTypedDict
    from .jobcreate import JobCreate, JobCreateTypedDict
    from .jobdatasetgenerationresponse import (
        JobDatasetGenerationResponse,
        JobDatasetGenerationResponseTypedDict,
    )
    from .joblistresponse import JobListResponse, JobListResponseTypedDict
    from .jobresponse import JobResponse, JobResponseTypedDict
    from .jwtpayload import JWTPayload, JWTPayloadTypedDict
    from .jwttoken import JWTToken, JWTTokenTypedDict
    from .list_job_batches_for_job_jobs_job_id_batches_getop import (
        ListJobBatchesForJobJobsJobIDBatchesGetRequest,
        ListJobBatchesForJobJobsJobIDBatchesGetRequestTypedDict,
    )
    from .list_jobs_for_project_projects_project_id_jobs_getop import (
        ListJobsForProjectProjectsProjectIDJobsGetRequest,
        ListJobsForProjectProjectsProjectIDJobsGetRequestTypedDict,
    )
    from .list_project_validators_projects_project_id_validators_getop import (
        ListProjectValidatorsProjectsProjectIDValidatorsGetRequest,
        ListProjectValidatorsProjectsProjectIDValidatorsGetRequestTypedDict,
    )
    from .list_projects_projects_getop import (
        ListProjectsProjectsGetRequest,
        ListProjectsProjectsGetRequestTypedDict,
    )
    from .list_stages_stages_getop import (
        ListStagesStagesGetRequest,
        ListStagesStagesGetRequestTypedDict,
    )
    from .list_test_cases_test_cases_getop import (
        ListTestCasesTestCasesGetRequest,
        ListTestCasesTestCasesGetRequestTypedDict,
    )
    from .list_user_api_keys_api_keys_getop import (
        ListUserAPIKeysAPIKeysGetRequest,
        ListUserAPIKeysAPIKeysGetRequestTypedDict,
    )
    from .list_validations_validations_getop import (
        ListValidationsValidationsGetRequest,
        ListValidationsValidationsGetRequestTypedDict,
    )
    from .listapikeyitem import ListAPIKeyItem, ListAPIKeyItemTypedDict
    from .listapikeysresponse import ListAPIKeysResponse, ListAPIKeysResponseTypedDict
    from .load_test_cases_for_validator_validator_tasks_validator_task_id_test_cases_getop import (
        LoadTestCasesForValidatorValidatorTasksValidatorTaskIDTestCasesGetRequest,
        LoadTestCasesForValidatorValidatorTasksValidatorTaskIDTestCasesGetRequestTypedDict,
    )
    from .message import Message, MessageTypedDict
    from .messagestepcreate import MessageStepCreate, MessageStepCreateTypedDict
    from .paginatedresponse_testcasevalidationread_ import (
        PaginatedResponseTestCaseValidationRead,
        PaginatedResponseTestCaseValidationReadTypedDict,
    )
    from .paginationdetails import PaginationDetails, PaginationDetailsTypedDict
    from .paginationinfo import PaginationInfo, PaginationInfoTypedDict
    from .prefect_webhook_integrations_prefect_webhook_postop import (
        PrefectWebhookIntegrationsPrefectWebhookPostRequest,
        PrefectWebhookIntegrationsPrefectWebhookPostRequestTypedDict,
    )
    from .prefectflowruninfo import PrefectFlowRunInfo, PrefectFlowRunInfoTypedDict
    from .prefectwebhookpayload import (
        PrefectWebhookPayload,
        PrefectWebhookPayloadTypedDict,
    )
    from .projectarchiveresponse import (
        ProjectArchiveResponse,
        ProjectArchiveResponseTypedDict,
    )
    from .projectcreate import ProjectCreate, ProjectCreateTypedDict
    from .projectlistresponse import ProjectListResponse, ProjectListResponseTypedDict
    from .projectresponse import ProjectResponse, ProjectResponseTypedDict
    from .projectupdate import ProjectUpdate, ProjectUpdateTypedDict
    from .projectvalidatorcreate import (
        ProjectValidatorCreate,
        ProjectValidatorCreateTypedDict,
    )
    from .projectvalidatorlistresponse import (
        ProjectValidatorListResponse,
        ProjectValidatorListResponseTypedDict,
    )
    from .projectvalidatorresponse import (
        ProjectValidatorResponse,
        ProjectValidatorResponseTypedDict,
    )
    from .remove_project_validator_projects_project_id_validators_validator_id_deleteop import (
        RemoveProjectValidatorProjectsProjectIDValidatorsValidatorIDDeleteRequest,
        RemoveProjectValidatorProjectsProjectIDValidatorsValidatorIDDeleteRequestTypedDict,
    )
    from .revoke_api_key_api_keys_key_id_deleteop import (
        RevokeAPIKeyAPIKeysKeyIDDeleteRequest,
        RevokeAPIKeyAPIKeysKeyIDDeleteRequestTypedDict,
    )
    from .stagedetailsresponse import (
        StageDetailsResponse,
        StageDetailsResponseTypedDict,
    )
    from .stagefiletypeenum import StageFileTypeEnum
    from .stagelistresponse import StageListResponse, StageListResponseTypedDict
    from .stageupdatepayload import StageUpdatePayload, StageUpdatePayloadTypedDict
    from .submit_test_case_validation_validator_tasks_validator_task_id_validations_postop import (
        SubmitTestCaseValidationValidatorTasksValidatorTaskIDValidationsPostRequest,
        SubmitTestCaseValidationValidatorTasksValidatorTaskIDValidationsPostRequestTypedDict,
    )
    from .submit_validator_task_validator_tasks_validator_task_id_submit_postop import (
        SubmitValidatorTaskValidatorTasksValidatorTaskIDSubmitPostRequest,
        SubmitValidatorTaskValidatorTasksValidatorTaskIDSubmitPostRequestTypedDict,
    )
    from .testcasecreate import (
        TestCaseCreate,
        TestCaseCreateTypedDict,
        Trajectory,
        TrajectoryTypedDict,
    )
    from .testcaseread import TestCaseRead, TestCaseReadTypedDict
    from .testcaseupdate import TestCaseUpdate, TestCaseUpdateTypedDict
    from .testcasevalidationcreate import (
        TestCaseValidationCreate,
        TestCaseValidationCreateTypedDict,
    )
    from .testcasevalidationread import (
        TestCaseValidationRead,
        TestCaseValidationReadTypedDict,
    )
    from .testcasevalidationupdate import (
        TestCaseValidationUpdate,
        TestCaseValidationUpdateTypedDict,
    )
    from .toolcall import ToolCall, ToolCallTypedDict
    from .toolcallstepcreate import ToolCallStepCreate, ToolCallStepCreateTypedDict
    from .tooloutput import ToolOutput, ToolOutputTypedDict
    from .trajectoryitem import ItemType, TrajectoryItem, TrajectoryItemTypedDict
    from .trigger_pipeline_from_stages_jobs_trigger_pipeline_from_stages_postop import (
        TriggerPipelineFromStagesJobsTriggerPipelineFromStagesPostRequest,
        TriggerPipelineFromStagesJobsTriggerPipelineFromStagesPostRequestTypedDict,
    )
    from .update_api_key_details_api_keys_key_id_putop import (
        UpdateAPIKeyDetailsAPIKeysKeyIDPutRequest,
        UpdateAPIKeyDetailsAPIKeysKeyIDPutRequestTypedDict,
    )
    from .update_project_projects_project_id_patchop import (
        UpdateProjectProjectsProjectIDPatchRequest,
        UpdateProjectProjectsProjectIDPatchRequestTypedDict,
    )
    from .update_stage_stages_stage_id_putop import (
        UpdateStageStagesStageIDPutRequest,
        UpdateStageStagesStageIDPutRequestTypedDict,
    )
    from .update_test_case_test_cases_test_case_id_putop import (
        UpdateTestCaseTestCasesTestCaseIDPutRequest,
        UpdateTestCaseTestCasesTestCaseIDPutRequestTypedDict,
    )
    from .update_test_case_validation_validations_validation_id_putop import (
        UpdateTestCaseValidationValidationsValidationIDPutRequest,
        UpdateTestCaseValidationValidationsValidationIDPutRequestTypedDict,
    )
    from .update_user_me_users_me_patchop import (
        UpdateUserMeUsersMePatchRequest,
        UpdateUserMeUsersMePatchRequestTypedDict,
    )
    from .update_user_role_users_role_patchop import (
        UpdateUserRoleUsersRolePatchRequest,
        UpdateUserRoleUsersRolePatchRequestTypedDict,
    )
    from .userread import UserRead, UserReadTypedDict
    from .userroleupdate import Role, UserRoleUpdate, UserRoleUpdateTypedDict
    from .userupdate import UserUpdate, UserUpdateTypedDict
    from .validationerror import (
        Loc,
        LocTypedDict,
        ValidationError,
        ValidationErrorTypedDict,
    )
    from .validationitemfeedback import (
        ValidationItemFeedback,
        ValidationItemFeedbackTypedDict,
    )
    from .validationitemfeedbackinput import (
        ValidationItemFeedbackInput,
        ValidationItemFeedbackInputTypedDict,
    )
    from .validationtaskread import ValidationTaskRead, ValidationTaskReadTypedDict
    from .validatorcompletesignuprequest import (
        ValidatorCompleteSignupRequest,
        ValidatorCompleteSignupRequestTypedDict,
    )
    from .validatortaskdetailschema import (
        ValidatorTaskDetailSchema,
        ValidatorTaskDetailSchemaTypedDict,
    )
    from .validatorurlinfo import ValidatorURLInfo, ValidatorURLInfoTypedDict
    from .validatorverifyaccessrequest import (
        ValidatorVerifyAccessRequest,
        ValidatorVerifyAccessRequestTypedDict,
    )

__all__ = [
    "APIKeyCreate",
    "APIKeyCreateResponse",
    "APIKeyCreateResponseTypedDict",
    "APIKeyCreateTypedDict",
    "APIKeyInfo",
    "APIKeyInfoTypedDict",
    "APIKeyUpdate",
    "APIKeyUpdateTypedDict",
    "AddProjectValidatorProjectsProjectIDValidatorsPostRequest",
    "AddProjectValidatorProjectsProjectIDValidatorsPostRequestTypedDict",
    "ArchiveProjectProjectsProjectIDArchivePostRequest",
    "ArchiveProjectProjectsProjectIDArchivePostRequestTypedDict",
    "BatchRead",
    "BatchReadTypedDict",
    "BatchStatusRead",
    "BatchStatusReadTypedDict",
    "BodyCreateStagesForProjectStagesPost",
    "BodyCreateStagesForProjectStagesPostTypedDict",
    "BodyUpdateTestCaseTestCasesTestCaseIDPut",
    "BodyUpdateTestCaseTestCasesTestCaseIDPutTypedDict",
    "CancelJobByIDJobsJobIDCancelPostRequest",
    "CancelJobByIDJobsJobIDCancelPostRequestTypedDict",
    "CheckValidationTaskStatusValidationTasksValidationTaskIDGetRequest",
    "CheckValidationTaskStatusValidationTasksValidationTaskIDGetRequestTypedDict",
    "CreateJobForProjectProjectsProjectIDJobsPostRequest",
    "CreateJobForProjectProjectsProjectIDJobsPostRequestTypedDict",
    "CreateTestCaseTestCasesPostRequest",
    "CreateTestCaseTestCasesPostRequestTypedDict",
    "CreateTestCaseValidationValidationsPostRequest",
    "CreateTestCaseValidationValidationsPostRequestTypedDict",
    "CreateValidationTaskForBatchEndpointBatchesBatchIDValidationTasksPostRequest",
    "CreateValidationTaskForBatchEndpointBatchesBatchIDValidationTasksPostRequestTypedDict",
    "CreateValidationTaskResponse",
    "CreateValidationTaskResponseTypedDict",
    "DatasetGenerationRequest",
    "DatasetGenerationRequestTypedDict",
    "DatasetItemListResponse",
    "DatasetItemListResponseTypedDict",
    "DatasetItemRead",
    "DatasetItemReadTypedDict",
    "DatasetRead",
    "DatasetReadTypedDict",
    "DeleteBatchByIDBatchesBatchIDDeleteRequest",
    "DeleteBatchByIDBatchesBatchIDDeleteRequestTypedDict",
    "DeleteDatasetDatasetsDatasetIDDeleteRequest",
    "DeleteDatasetDatasetsDatasetIDDeleteRequestTypedDict",
    "DeleteProjectProjectsProjectIDDeleteRequest",
    "DeleteProjectProjectsProjectIDDeleteRequestTypedDict",
    "DeleteStageStagesStageIDDeleteRequest",
    "DeleteStageStagesStageIDDeleteRequestTypedDict",
    "DeleteTestCaseTestCasesTestCaseIDDeleteRequest",
    "DeleteTestCaseTestCasesTestCaseIDDeleteRequestTypedDict",
    "DeleteValidationValidationsValidationIDDeleteRequest",
    "DeleteValidationValidationsValidationIDDeleteRequestTypedDict",
    "EditTestCaseValidationValidatorTasksValidatorTaskIDValidationsValidationIDPutRequest",
    "EditTestCaseValidationValidatorTasksValidatorTaskIDValidationsValidationIDPutRequestTypedDict",
    "File",
    "FileTypedDict",
    "GenerateBatchForJobJobsJobIDGenerateBatchPostRequest",
    "GenerateBatchForJobJobsJobIDGenerateBatchPostRequestTypedDict",
    "GenerateDatasetForJobJobsJobIDGenerateDatasetPostRequest",
    "GenerateDatasetForJobJobsJobIDGenerateDatasetPostRequestTypedDict",
    "GetBatchByIDBatchesBatchIDGetRequest",
    "GetBatchByIDBatchesBatchIDGetRequestTypedDict",
    "GetBatchStatusEndpointBatchesBatchIDStatusGetRequest",
    "GetBatchStatusEndpointBatchesBatchIDStatusGetRequestTypedDict",
    "GetBatchTestCasesBatchesBatchIDTestcasesGetRequest",
    "GetBatchTestCasesBatchesBatchIDTestcasesGetRequestTypedDict",
    "GetDatasetItemsDatasetsDatasetIDItemsGetRequest",
    "GetDatasetItemsDatasetsDatasetIDItemsGetRequestTypedDict",
    "GetJobDetailsJobsJobIDGetRequest",
    "GetJobDetailsJobsJobIDGetRequestTypedDict",
    "GetProjectDatasetProjectsProjectIDDatasetGetRequest",
    "GetProjectDatasetProjectsProjectIDDatasetGetRequestTypedDict",
    "GetProjectProjectsProjectIDGetRequest",
    "GetProjectProjectsProjectIDGetRequestTypedDict",
    "GetSingleValidationFromBatchTestCasesTestCaseIDValidationGetRequest",
    "GetSingleValidationFromBatchTestCasesTestCaseIDValidationGetRequestTypedDict",
    "GetStageDetailsStagesStageIDGetRequest",
    "GetStageDetailsStagesStageIDGetRequestTypedDict",
    "GetTestCaseTestCasesTestCaseIDGetRequest",
    "GetTestCaseTestCasesTestCaseIDGetRequestTypedDict",
    "GetValidationTaskForBatchEndpointBatchesBatchIDValidationTaskGetRequest",
    "GetValidationTaskForBatchEndpointBatchesBatchIDValidationTaskGetRequestTypedDict",
    "GetValidationTaskForBatchResponseSchema",
    "GetValidationTaskForBatchResponseSchemaTypedDict",
    "GetValidationValidationsValidationIDGetRequest",
    "GetValidationValidationsValidationIDGetRequestTypedDict",
    "GetValidationsForBatchBatchesBatchIDValidationsGetRequest",
    "GetValidationsForBatchBatchesBatchIDValidationsGetRequestTypedDict",
    "HandleClerkWebhookEndpointClerkWebhooksPostRequest",
    "HandleClerkWebhookEndpointClerkWebhooksPostRequestTypedDict",
    "ItemType",
    "JWTPayload",
    "JWTPayloadTypedDict",
    "JWTToken",
    "JWTTokenTypedDict",
    "JobBatchGenerationResponse",
    "JobBatchGenerationResponseTypedDict",
    "JobCancelResponse",
    "JobCancelResponseTypedDict",
    "JobCreate",
    "JobCreateTypedDict",
    "JobDatasetGenerationResponse",
    "JobDatasetGenerationResponseTypedDict",
    "JobListResponse",
    "JobListResponseTypedDict",
    "JobResponse",
    "JobResponseTypedDict",
    "ListAPIKeyItem",
    "ListAPIKeyItemTypedDict",
    "ListAPIKeysResponse",
    "ListAPIKeysResponseTypedDict",
    "ListJobBatchesForJobJobsJobIDBatchesGetRequest",
    "ListJobBatchesForJobJobsJobIDBatchesGetRequestTypedDict",
    "ListJobsForProjectProjectsProjectIDJobsGetRequest",
    "ListJobsForProjectProjectsProjectIDJobsGetRequestTypedDict",
    "ListProjectValidatorsProjectsProjectIDValidatorsGetRequest",
    "ListProjectValidatorsProjectsProjectIDValidatorsGetRequestTypedDict",
    "ListProjectsProjectsGetRequest",
    "ListProjectsProjectsGetRequestTypedDict",
    "ListStagesStagesGetRequest",
    "ListStagesStagesGetRequestTypedDict",
    "ListTestCasesTestCasesGetRequest",
    "ListTestCasesTestCasesGetRequestTypedDict",
    "ListUserAPIKeysAPIKeysGetRequest",
    "ListUserAPIKeysAPIKeysGetRequestTypedDict",
    "ListValidationsValidationsGetRequest",
    "ListValidationsValidationsGetRequestTypedDict",
    "LoadTestCasesForValidatorValidatorTasksValidatorTaskIDTestCasesGetRequest",
    "LoadTestCasesForValidatorValidatorTasksValidatorTaskIDTestCasesGetRequestTypedDict",
    "Loc",
    "LocTypedDict",
    "Message",
    "MessageStepCreate",
    "MessageStepCreateTypedDict",
    "MessageTypedDict",
    "PaginatedResponseTestCaseValidationRead",
    "PaginatedResponseTestCaseValidationReadTypedDict",
    "PaginationDetails",
    "PaginationDetailsTypedDict",
    "PaginationInfo",
    "PaginationInfoTypedDict",
    "PrefectFlowRunInfo",
    "PrefectFlowRunInfoTypedDict",
    "PrefectWebhookIntegrationsPrefectWebhookPostRequest",
    "PrefectWebhookIntegrationsPrefectWebhookPostRequestTypedDict",
    "PrefectWebhookPayload",
    "PrefectWebhookPayloadTypedDict",
    "ProjectArchiveResponse",
    "ProjectArchiveResponseTypedDict",
    "ProjectCreate",
    "ProjectCreateTypedDict",
    "ProjectListResponse",
    "ProjectListResponseTypedDict",
    "ProjectResponse",
    "ProjectResponseTypedDict",
    "ProjectUpdate",
    "ProjectUpdateTypedDict",
    "ProjectValidatorCreate",
    "ProjectValidatorCreateTypedDict",
    "ProjectValidatorListResponse",
    "ProjectValidatorListResponseTypedDict",
    "ProjectValidatorResponse",
    "ProjectValidatorResponseTypedDict",
    "RemoveProjectValidatorProjectsProjectIDValidatorsValidatorIDDeleteRequest",
    "RemoveProjectValidatorProjectsProjectIDValidatorsValidatorIDDeleteRequestTypedDict",
    "RevokeAPIKeyAPIKeysKeyIDDeleteRequest",
    "RevokeAPIKeyAPIKeysKeyIDDeleteRequestTypedDict",
    "Role",
    "StageDetailsResponse",
    "StageDetailsResponseTypedDict",
    "StageFileTypeEnum",
    "StageListResponse",
    "StageListResponseTypedDict",
    "StageUpdatePayload",
    "StageUpdatePayloadTypedDict",
    "SubmitTestCaseValidationValidatorTasksValidatorTaskIDValidationsPostRequest",
    "SubmitTestCaseValidationValidatorTasksValidatorTaskIDValidationsPostRequestTypedDict",
    "SubmitValidatorTaskValidatorTasksValidatorTaskIDSubmitPostRequest",
    "SubmitValidatorTaskValidatorTasksValidatorTaskIDSubmitPostRequestTypedDict",
    "TestCaseCreate",
    "TestCaseCreateTypedDict",
    "TestCaseRead",
    "TestCaseReadTypedDict",
    "TestCaseUpdate",
    "TestCaseUpdateTypedDict",
    "TestCaseValidationCreate",
    "TestCaseValidationCreateTypedDict",
    "TestCaseValidationRead",
    "TestCaseValidationReadTypedDict",
    "TestCaseValidationUpdate",
    "TestCaseValidationUpdateTypedDict",
    "ToolCall",
    "ToolCallStepCreate",
    "ToolCallStepCreateTypedDict",
    "ToolCallTypedDict",
    "ToolOutput",
    "ToolOutputTypedDict",
    "Trajectory",
    "TrajectoryItem",
    "TrajectoryItemTypedDict",
    "TrajectoryTypedDict",
    "TriggerPipelineFromStagesJobsTriggerPipelineFromStagesPostRequest",
    "TriggerPipelineFromStagesJobsTriggerPipelineFromStagesPostRequestTypedDict",
    "UpdateAPIKeyDetailsAPIKeysKeyIDPutRequest",
    "UpdateAPIKeyDetailsAPIKeysKeyIDPutRequestTypedDict",
    "UpdateProjectProjectsProjectIDPatchRequest",
    "UpdateProjectProjectsProjectIDPatchRequestTypedDict",
    "UpdateStageStagesStageIDPutRequest",
    "UpdateStageStagesStageIDPutRequestTypedDict",
    "UpdateTestCaseTestCasesTestCaseIDPutRequest",
    "UpdateTestCaseTestCasesTestCaseIDPutRequestTypedDict",
    "UpdateTestCaseValidationValidationsValidationIDPutRequest",
    "UpdateTestCaseValidationValidationsValidationIDPutRequestTypedDict",
    "UpdateUserMeUsersMePatchRequest",
    "UpdateUserMeUsersMePatchRequestTypedDict",
    "UpdateUserRoleUsersRolePatchRequest",
    "UpdateUserRoleUsersRolePatchRequestTypedDict",
    "UserRead",
    "UserReadTypedDict",
    "UserRoleUpdate",
    "UserRoleUpdateTypedDict",
    "UserUpdate",
    "UserUpdateTypedDict",
    "ValidationError",
    "ValidationErrorTypedDict",
    "ValidationItemFeedback",
    "ValidationItemFeedbackInput",
    "ValidationItemFeedbackInputTypedDict",
    "ValidationItemFeedbackTypedDict",
    "ValidationTaskRead",
    "ValidationTaskReadTypedDict",
    "ValidatorCompleteSignupRequest",
    "ValidatorCompleteSignupRequestTypedDict",
    "ValidatorTaskDetailSchema",
    "ValidatorTaskDetailSchemaTypedDict",
    "ValidatorURLInfo",
    "ValidatorURLInfoTypedDict",
    "ValidatorVerifyAccessRequest",
    "ValidatorVerifyAccessRequestTypedDict",
]

_dynamic_imports: dict[str, str] = {
    "AddProjectValidatorProjectsProjectIDValidatorsPostRequest": ".add_project_validator_projects_project_id_validators_postop",
    "AddProjectValidatorProjectsProjectIDValidatorsPostRequestTypedDict": ".add_project_validator_projects_project_id_validators_postop",
    "APIKeyCreate": ".apikeycreate",
    "APIKeyCreateTypedDict": ".apikeycreate",
    "APIKeyCreateResponse": ".apikeycreateresponse",
    "APIKeyCreateResponseTypedDict": ".apikeycreateresponse",
    "APIKeyInfo": ".apikeyinfo",
    "APIKeyInfoTypedDict": ".apikeyinfo",
    "APIKeyUpdate": ".apikeyupdate",
    "APIKeyUpdateTypedDict": ".apikeyupdate",
    "ArchiveProjectProjectsProjectIDArchivePostRequest": ".archive_project_projects_project_id_archive_postop",
    "ArchiveProjectProjectsProjectIDArchivePostRequestTypedDict": ".archive_project_projects_project_id_archive_postop",
    "BatchRead": ".batchread",
    "BatchReadTypedDict": ".batchread",
    "BatchStatusRead": ".batchstatusread",
    "BatchStatusReadTypedDict": ".batchstatusread",
    "BodyCreateStagesForProjectStagesPost": ".body_create_stages_for_project_stages_post",
    "BodyCreateStagesForProjectStagesPostTypedDict": ".body_create_stages_for_project_stages_post",
    "File": ".body_create_stages_for_project_stages_post",
    "FileTypedDict": ".body_create_stages_for_project_stages_post",
    "BodyUpdateTestCaseTestCasesTestCaseIDPut": ".body_update_test_case_test_cases_test_case_id_put",
    "BodyUpdateTestCaseTestCasesTestCaseIDPutTypedDict": ".body_update_test_case_test_cases_test_case_id_put",
    "CancelJobByIDJobsJobIDCancelPostRequest": ".cancel_job_by_id_jobs_job_id_cancel_postop",
    "CancelJobByIDJobsJobIDCancelPostRequestTypedDict": ".cancel_job_by_id_jobs_job_id_cancel_postop",
    "CheckValidationTaskStatusValidationTasksValidationTaskIDGetRequest": ".check_validation_task_status_validation_tasks_validation_task_id_getop",
    "CheckValidationTaskStatusValidationTasksValidationTaskIDGetRequestTypedDict": ".check_validation_task_status_validation_tasks_validation_task_id_getop",
    "CreateJobForProjectProjectsProjectIDJobsPostRequest": ".create_job_for_project_projects_project_id_jobs_postop",
    "CreateJobForProjectProjectsProjectIDJobsPostRequestTypedDict": ".create_job_for_project_projects_project_id_jobs_postop",
    "CreateTestCaseTestCasesPostRequest": ".create_test_case_test_cases_postop",
    "CreateTestCaseTestCasesPostRequestTypedDict": ".create_test_case_test_cases_postop",
    "CreateTestCaseValidationValidationsPostRequest": ".create_test_case_validation_validations_postop",
    "CreateTestCaseValidationValidationsPostRequestTypedDict": ".create_test_case_validation_validations_postop",
    "CreateValidationTaskForBatchEndpointBatchesBatchIDValidationTasksPostRequest": ".create_validation_task_for_batch_endpoint_batches_batch_id_validation_tasks_postop",
    "CreateValidationTaskForBatchEndpointBatchesBatchIDValidationTasksPostRequestTypedDict": ".create_validation_task_for_batch_endpoint_batches_batch_id_validation_tasks_postop",
    "CreateValidationTaskResponse": ".createvalidationtaskresponse",
    "CreateValidationTaskResponseTypedDict": ".createvalidationtaskresponse",
    "DatasetGenerationRequest": ".datasetgenerationrequest",
    "DatasetGenerationRequestTypedDict": ".datasetgenerationrequest",
    "DatasetItemListResponse": ".datasetitemlistresponse",
    "DatasetItemListResponseTypedDict": ".datasetitemlistresponse",
    "DatasetItemRead": ".datasetitemread",
    "DatasetItemReadTypedDict": ".datasetitemread",
    "DatasetRead": ".datasetread",
    "DatasetReadTypedDict": ".datasetread",
    "DeleteBatchByIDBatchesBatchIDDeleteRequest": ".delete_batch_by_id_batches_batch_id_deleteop",
    "DeleteBatchByIDBatchesBatchIDDeleteRequestTypedDict": ".delete_batch_by_id_batches_batch_id_deleteop",
    "DeleteDatasetDatasetsDatasetIDDeleteRequest": ".delete_dataset_datasets_dataset_id_deleteop",
    "DeleteDatasetDatasetsDatasetIDDeleteRequestTypedDict": ".delete_dataset_datasets_dataset_id_deleteop",
    "DeleteProjectProjectsProjectIDDeleteRequest": ".delete_project_projects_project_id_deleteop",
    "DeleteProjectProjectsProjectIDDeleteRequestTypedDict": ".delete_project_projects_project_id_deleteop",
    "DeleteStageStagesStageIDDeleteRequest": ".delete_stage_stages_stage_id_deleteop",
    "DeleteStageStagesStageIDDeleteRequestTypedDict": ".delete_stage_stages_stage_id_deleteop",
    "DeleteTestCaseTestCasesTestCaseIDDeleteRequest": ".delete_test_case_test_cases_test_case_id_deleteop",
    "DeleteTestCaseTestCasesTestCaseIDDeleteRequestTypedDict": ".delete_test_case_test_cases_test_case_id_deleteop",
    "DeleteValidationValidationsValidationIDDeleteRequest": ".delete_validation_validations_validation_id_deleteop",
    "DeleteValidationValidationsValidationIDDeleteRequestTypedDict": ".delete_validation_validations_validation_id_deleteop",
    "EditTestCaseValidationValidatorTasksValidatorTaskIDValidationsValidationIDPutRequest": ".edit_test_case_validation_validator_tasks_validator_task_id_validations_validation_id_putop",
    "EditTestCaseValidationValidatorTasksValidatorTaskIDValidationsValidationIDPutRequestTypedDict": ".edit_test_case_validation_validator_tasks_validator_task_id_validations_validation_id_putop",
    "GenerateBatchForJobJobsJobIDGenerateBatchPostRequest": ".generate_batch_for_job_jobs_job_id_generate_batch_postop",
    "GenerateBatchForJobJobsJobIDGenerateBatchPostRequestTypedDict": ".generate_batch_for_job_jobs_job_id_generate_batch_postop",
    "GenerateDatasetForJobJobsJobIDGenerateDatasetPostRequest": ".generate_dataset_for_job_jobs_job_id_generate_dataset_postop",
    "GenerateDatasetForJobJobsJobIDGenerateDatasetPostRequestTypedDict": ".generate_dataset_for_job_jobs_job_id_generate_dataset_postop",
    "GetBatchByIDBatchesBatchIDGetRequest": ".get_batch_by_id_batches_batch_id_getop",
    "GetBatchByIDBatchesBatchIDGetRequestTypedDict": ".get_batch_by_id_batches_batch_id_getop",
    "GetBatchStatusEndpointBatchesBatchIDStatusGetRequest": ".get_batch_status_endpoint_batches_batch_id_status_getop",
    "GetBatchStatusEndpointBatchesBatchIDStatusGetRequestTypedDict": ".get_batch_status_endpoint_batches_batch_id_status_getop",
    "GetBatchTestCasesBatchesBatchIDTestcasesGetRequest": ".get_batch_test_cases_batches_batch_id_testcases_getop",
    "GetBatchTestCasesBatchesBatchIDTestcasesGetRequestTypedDict": ".get_batch_test_cases_batches_batch_id_testcases_getop",
    "GetDatasetItemsDatasetsDatasetIDItemsGetRequest": ".get_dataset_items_datasets_dataset_id_items_getop",
    "GetDatasetItemsDatasetsDatasetIDItemsGetRequestTypedDict": ".get_dataset_items_datasets_dataset_id_items_getop",
    "GetJobDetailsJobsJobIDGetRequest": ".get_job_details_jobs_job_id_getop",
    "GetJobDetailsJobsJobIDGetRequestTypedDict": ".get_job_details_jobs_job_id_getop",
    "GetProjectDatasetProjectsProjectIDDatasetGetRequest": ".get_project_dataset_projects_project_id_dataset_getop",
    "GetProjectDatasetProjectsProjectIDDatasetGetRequestTypedDict": ".get_project_dataset_projects_project_id_dataset_getop",
    "GetProjectProjectsProjectIDGetRequest": ".get_project_projects_project_id_getop",
    "GetProjectProjectsProjectIDGetRequestTypedDict": ".get_project_projects_project_id_getop",
    "GetSingleValidationFromBatchTestCasesTestCaseIDValidationGetRequest": ".get_single_validation_from_batch_test_cases_test_case_id_validation_getop",
    "GetSingleValidationFromBatchTestCasesTestCaseIDValidationGetRequestTypedDict": ".get_single_validation_from_batch_test_cases_test_case_id_validation_getop",
    "GetStageDetailsStagesStageIDGetRequest": ".get_stage_details_stages_stage_id_getop",
    "GetStageDetailsStagesStageIDGetRequestTypedDict": ".get_stage_details_stages_stage_id_getop",
    "GetTestCaseTestCasesTestCaseIDGetRequest": ".get_test_case_test_cases_test_case_id_getop",
    "GetTestCaseTestCasesTestCaseIDGetRequestTypedDict": ".get_test_case_test_cases_test_case_id_getop",
    "GetValidationTaskForBatchEndpointBatchesBatchIDValidationTaskGetRequest": ".get_validation_task_for_batch_endpoint_batches_batch_id_validation_task_getop",
    "GetValidationTaskForBatchEndpointBatchesBatchIDValidationTaskGetRequestTypedDict": ".get_validation_task_for_batch_endpoint_batches_batch_id_validation_task_getop",
    "GetValidationValidationsValidationIDGetRequest": ".get_validation_validations_validation_id_getop",
    "GetValidationValidationsValidationIDGetRequestTypedDict": ".get_validation_validations_validation_id_getop",
    "GetValidationsForBatchBatchesBatchIDValidationsGetRequest": ".get_validations_for_batch_batches_batch_id_validations_getop",
    "GetValidationsForBatchBatchesBatchIDValidationsGetRequestTypedDict": ".get_validations_for_batch_batches_batch_id_validations_getop",
    "GetValidationTaskForBatchResponseSchema": ".getvalidationtaskforbatchresponseschema",
    "GetValidationTaskForBatchResponseSchemaTypedDict": ".getvalidationtaskforbatchresponseschema",
    "HandleClerkWebhookEndpointClerkWebhooksPostRequest": ".handle_clerk_webhook_endpoint_clerk_webhooks_postop",
    "HandleClerkWebhookEndpointClerkWebhooksPostRequestTypedDict": ".handle_clerk_webhook_endpoint_clerk_webhooks_postop",
    "JobBatchGenerationResponse": ".jobbatchgenerationresponse",
    "JobBatchGenerationResponseTypedDict": ".jobbatchgenerationresponse",
    "JobCancelResponse": ".jobcancelresponse",
    "JobCancelResponseTypedDict": ".jobcancelresponse",
    "JobCreate": ".jobcreate",
    "JobCreateTypedDict": ".jobcreate",
    "JobDatasetGenerationResponse": ".jobdatasetgenerationresponse",
    "JobDatasetGenerationResponseTypedDict": ".jobdatasetgenerationresponse",
    "JobListResponse": ".joblistresponse",
    "JobListResponseTypedDict": ".joblistresponse",
    "JobResponse": ".jobresponse",
    "JobResponseTypedDict": ".jobresponse",
    "JWTPayload": ".jwtpayload",
    "JWTPayloadTypedDict": ".jwtpayload",
    "JWTToken": ".jwttoken",
    "JWTTokenTypedDict": ".jwttoken",
    "ListJobBatchesForJobJobsJobIDBatchesGetRequest": ".list_job_batches_for_job_jobs_job_id_batches_getop",
    "ListJobBatchesForJobJobsJobIDBatchesGetRequestTypedDict": ".list_job_batches_for_job_jobs_job_id_batches_getop",
    "ListJobsForProjectProjectsProjectIDJobsGetRequest": ".list_jobs_for_project_projects_project_id_jobs_getop",
    "ListJobsForProjectProjectsProjectIDJobsGetRequestTypedDict": ".list_jobs_for_project_projects_project_id_jobs_getop",
    "ListProjectValidatorsProjectsProjectIDValidatorsGetRequest": ".list_project_validators_projects_project_id_validators_getop",
    "ListProjectValidatorsProjectsProjectIDValidatorsGetRequestTypedDict": ".list_project_validators_projects_project_id_validators_getop",
    "ListProjectsProjectsGetRequest": ".list_projects_projects_getop",
    "ListProjectsProjectsGetRequestTypedDict": ".list_projects_projects_getop",
    "ListStagesStagesGetRequest": ".list_stages_stages_getop",
    "ListStagesStagesGetRequestTypedDict": ".list_stages_stages_getop",
    "ListTestCasesTestCasesGetRequest": ".list_test_cases_test_cases_getop",
    "ListTestCasesTestCasesGetRequestTypedDict": ".list_test_cases_test_cases_getop",
    "ListUserAPIKeysAPIKeysGetRequest": ".list_user_api_keys_api_keys_getop",
    "ListUserAPIKeysAPIKeysGetRequestTypedDict": ".list_user_api_keys_api_keys_getop",
    "ListValidationsValidationsGetRequest": ".list_validations_validations_getop",
    "ListValidationsValidationsGetRequestTypedDict": ".list_validations_validations_getop",
    "ListAPIKeyItem": ".listapikeyitem",
    "ListAPIKeyItemTypedDict": ".listapikeyitem",
    "ListAPIKeysResponse": ".listapikeysresponse",
    "ListAPIKeysResponseTypedDict": ".listapikeysresponse",
    "LoadTestCasesForValidatorValidatorTasksValidatorTaskIDTestCasesGetRequest": ".load_test_cases_for_validator_validator_tasks_validator_task_id_test_cases_getop",
    "LoadTestCasesForValidatorValidatorTasksValidatorTaskIDTestCasesGetRequestTypedDict": ".load_test_cases_for_validator_validator_tasks_validator_task_id_test_cases_getop",
    "Message": ".message",
    "MessageTypedDict": ".message",
    "MessageStepCreate": ".messagestepcreate",
    "MessageStepCreateTypedDict": ".messagestepcreate",
    "PaginatedResponseTestCaseValidationRead": ".paginatedresponse_testcasevalidationread_",
    "PaginatedResponseTestCaseValidationReadTypedDict": ".paginatedresponse_testcasevalidationread_",
    "PaginationDetails": ".paginationdetails",
    "PaginationDetailsTypedDict": ".paginationdetails",
    "PaginationInfo": ".paginationinfo",
    "PaginationInfoTypedDict": ".paginationinfo",
    "PrefectWebhookIntegrationsPrefectWebhookPostRequest": ".prefect_webhook_integrations_prefect_webhook_postop",
    "PrefectWebhookIntegrationsPrefectWebhookPostRequestTypedDict": ".prefect_webhook_integrations_prefect_webhook_postop",
    "PrefectFlowRunInfo": ".prefectflowruninfo",
    "PrefectFlowRunInfoTypedDict": ".prefectflowruninfo",
    "PrefectWebhookPayload": ".prefectwebhookpayload",
    "PrefectWebhookPayloadTypedDict": ".prefectwebhookpayload",
    "ProjectArchiveResponse": ".projectarchiveresponse",
    "ProjectArchiveResponseTypedDict": ".projectarchiveresponse",
    "ProjectCreate": ".projectcreate",
    "ProjectCreateTypedDict": ".projectcreate",
    "ProjectListResponse": ".projectlistresponse",
    "ProjectListResponseTypedDict": ".projectlistresponse",
    "ProjectResponse": ".projectresponse",
    "ProjectResponseTypedDict": ".projectresponse",
    "ProjectUpdate": ".projectupdate",
    "ProjectUpdateTypedDict": ".projectupdate",
    "ProjectValidatorCreate": ".projectvalidatorcreate",
    "ProjectValidatorCreateTypedDict": ".projectvalidatorcreate",
    "ProjectValidatorListResponse": ".projectvalidatorlistresponse",
    "ProjectValidatorListResponseTypedDict": ".projectvalidatorlistresponse",
    "ProjectValidatorResponse": ".projectvalidatorresponse",
    "ProjectValidatorResponseTypedDict": ".projectvalidatorresponse",
    "RemoveProjectValidatorProjectsProjectIDValidatorsValidatorIDDeleteRequest": ".remove_project_validator_projects_project_id_validators_validator_id_deleteop",
    "RemoveProjectValidatorProjectsProjectIDValidatorsValidatorIDDeleteRequestTypedDict": ".remove_project_validator_projects_project_id_validators_validator_id_deleteop",
    "RevokeAPIKeyAPIKeysKeyIDDeleteRequest": ".revoke_api_key_api_keys_key_id_deleteop",
    "RevokeAPIKeyAPIKeysKeyIDDeleteRequestTypedDict": ".revoke_api_key_api_keys_key_id_deleteop",
    "StageDetailsResponse": ".stagedetailsresponse",
    "StageDetailsResponseTypedDict": ".stagedetailsresponse",
    "StageFileTypeEnum": ".stagefiletypeenum",
    "StageListResponse": ".stagelistresponse",
    "StageListResponseTypedDict": ".stagelistresponse",
    "StageUpdatePayload": ".stageupdatepayload",
    "StageUpdatePayloadTypedDict": ".stageupdatepayload",
    "SubmitTestCaseValidationValidatorTasksValidatorTaskIDValidationsPostRequest": ".submit_test_case_validation_validator_tasks_validator_task_id_validations_postop",
    "SubmitTestCaseValidationValidatorTasksValidatorTaskIDValidationsPostRequestTypedDict": ".submit_test_case_validation_validator_tasks_validator_task_id_validations_postop",
    "SubmitValidatorTaskValidatorTasksValidatorTaskIDSubmitPostRequest": ".submit_validator_task_validator_tasks_validator_task_id_submit_postop",
    "SubmitValidatorTaskValidatorTasksValidatorTaskIDSubmitPostRequestTypedDict": ".submit_validator_task_validator_tasks_validator_task_id_submit_postop",
    "TestCaseCreate": ".testcasecreate",
    "TestCaseCreateTypedDict": ".testcasecreate",
    "Trajectory": ".testcasecreate",
    "TrajectoryTypedDict": ".testcasecreate",
    "TestCaseRead": ".testcaseread",
    "TestCaseReadTypedDict": ".testcaseread",
    "TestCaseUpdate": ".testcaseupdate",
    "TestCaseUpdateTypedDict": ".testcaseupdate",
    "TestCaseValidationCreate": ".testcasevalidationcreate",
    "TestCaseValidationCreateTypedDict": ".testcasevalidationcreate",
    "TestCaseValidationRead": ".testcasevalidationread",
    "TestCaseValidationReadTypedDict": ".testcasevalidationread",
    "TestCaseValidationUpdate": ".testcasevalidationupdate",
    "TestCaseValidationUpdateTypedDict": ".testcasevalidationupdate",
    "ToolCall": ".toolcall",
    "ToolCallTypedDict": ".toolcall",
    "ToolCallStepCreate": ".toolcallstepcreate",
    "ToolCallStepCreateTypedDict": ".toolcallstepcreate",
    "ToolOutput": ".tooloutput",
    "ToolOutputTypedDict": ".tooloutput",
    "ItemType": ".trajectoryitem",
    "TrajectoryItem": ".trajectoryitem",
    "TrajectoryItemTypedDict": ".trajectoryitem",
    "TriggerPipelineFromStagesJobsTriggerPipelineFromStagesPostRequest": ".trigger_pipeline_from_stages_jobs_trigger_pipeline_from_stages_postop",
    "TriggerPipelineFromStagesJobsTriggerPipelineFromStagesPostRequestTypedDict": ".trigger_pipeline_from_stages_jobs_trigger_pipeline_from_stages_postop",
    "UpdateAPIKeyDetailsAPIKeysKeyIDPutRequest": ".update_api_key_details_api_keys_key_id_putop",
    "UpdateAPIKeyDetailsAPIKeysKeyIDPutRequestTypedDict": ".update_api_key_details_api_keys_key_id_putop",
    "UpdateProjectProjectsProjectIDPatchRequest": ".update_project_projects_project_id_patchop",
    "UpdateProjectProjectsProjectIDPatchRequestTypedDict": ".update_project_projects_project_id_patchop",
    "UpdateStageStagesStageIDPutRequest": ".update_stage_stages_stage_id_putop",
    "UpdateStageStagesStageIDPutRequestTypedDict": ".update_stage_stages_stage_id_putop",
    "UpdateTestCaseTestCasesTestCaseIDPutRequest": ".update_test_case_test_cases_test_case_id_putop",
    "UpdateTestCaseTestCasesTestCaseIDPutRequestTypedDict": ".update_test_case_test_cases_test_case_id_putop",
    "UpdateTestCaseValidationValidationsValidationIDPutRequest": ".update_test_case_validation_validations_validation_id_putop",
    "UpdateTestCaseValidationValidationsValidationIDPutRequestTypedDict": ".update_test_case_validation_validations_validation_id_putop",
    "UpdateUserMeUsersMePatchRequest": ".update_user_me_users_me_patchop",
    "UpdateUserMeUsersMePatchRequestTypedDict": ".update_user_me_users_me_patchop",
    "UpdateUserRoleUsersRolePatchRequest": ".update_user_role_users_role_patchop",
    "UpdateUserRoleUsersRolePatchRequestTypedDict": ".update_user_role_users_role_patchop",
    "UserRead": ".userread",
    "UserReadTypedDict": ".userread",
    "Role": ".userroleupdate",
    "UserRoleUpdate": ".userroleupdate",
    "UserRoleUpdateTypedDict": ".userroleupdate",
    "UserUpdate": ".userupdate",
    "UserUpdateTypedDict": ".userupdate",
    "Loc": ".validationerror",
    "LocTypedDict": ".validationerror",
    "ValidationError": ".validationerror",
    "ValidationErrorTypedDict": ".validationerror",
    "ValidationItemFeedback": ".validationitemfeedback",
    "ValidationItemFeedbackTypedDict": ".validationitemfeedback",
    "ValidationItemFeedbackInput": ".validationitemfeedbackinput",
    "ValidationItemFeedbackInputTypedDict": ".validationitemfeedbackinput",
    "ValidationTaskRead": ".validationtaskread",
    "ValidationTaskReadTypedDict": ".validationtaskread",
    "ValidatorCompleteSignupRequest": ".validatorcompletesignuprequest",
    "ValidatorCompleteSignupRequestTypedDict": ".validatorcompletesignuprequest",
    "ValidatorTaskDetailSchema": ".validatortaskdetailschema",
    "ValidatorTaskDetailSchemaTypedDict": ".validatortaskdetailschema",
    "ValidatorURLInfo": ".validatorurlinfo",
    "ValidatorURLInfoTypedDict": ".validatorurlinfo",
    "ValidatorVerifyAccessRequest": ".validatorverifyaccessrequest",
    "ValidatorVerifyAccessRequestTypedDict": ".validatorverifyaccessrequest",
}


def __getattr__(attr_name: str) -> object:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(
            f"No {attr_name} found in _dynamic_imports for module name -> {__name__} "
        )

    try:
        module = import_module(module_name, __package__)
        result = getattr(module, attr_name)
        return result
    except ImportError as e:
        raise ImportError(
            f"Failed to import {attr_name} from {module_name}: {e}"
        ) from e
    except AttributeError as e:
        raise AttributeError(
            f"Failed to get {attr_name} from {module_name}: {e}"
        ) from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .testcasevalidationupdate import (
    TestCaseValidationUpdate,
    TestCaseValidationUpdateTypedDict,
)
from flowai_sdk.types import BaseModel
from flowai_sdk.utils import (
    FieldMetadata,
    PathParamMetadata,
    QueryParamMetadata,
    RequestMetadata,
)
from typing import Any
from typing_extensions import Annotated, TypedDict


class UpdateTestCaseValidationValidationsValidationIDPutRequestTypedDict(TypedDict):
    validation_id: str
    current_user_payload: Any
    test_case_validation_update: TestCaseValidationUpdateTypedDict


class UpdateTestCaseValidationValidationsValidationIDPutRequest(BaseModel):
    validation_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    current_user_payload: Annotated[
        Any, FieldMetadata(query=QueryParamMetadata(style="form", explode=True))
    ]

    test_case_validation_update: Annotated[
        TestCaseValidationUpdate,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flowai_sdk.types import BaseModel
from typing_extensions import TypedDict


class ProjectArchiveResponseTypedDict(TypedDict):
    id: str
    is_active: bool


class ProjectArchiveResponse(BaseModel):
    id: str

    is_active: bool



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .testcasevalidationread import (
    TestCaseValidationRead,
    TestCaseValidationReadTypedDict,
)
from flowai_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class PaginatedResponseTestCaseValidationReadTypedDict(TypedDict):
    items: List[TestCaseValidationReadTypedDict]
    total: int
    page: int
    pages: int
    has_more: bool


class PaginatedResponseTestCaseValidationRead(BaseModel):
    items: List[TestCaseValidationRead]

    total: int

    page: int

    pages: int

    has_more: bool



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .projectvalidatorresponse import (
    ProjectValidatorResponse,
    ProjectValidatorResponseTypedDict,
)
from flowai_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class ProjectValidatorListResponseTypedDict(TypedDict):
    r"""Schema for listing project validators."""

    validators: List[ProjectValidatorResponseTypedDict]


class ProjectValidatorListResponse(BaseModel):
    r"""Schema for listing project validators."""

    validators: List[ProjectValidatorResponse]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flowai_sdk.types import BaseModel
from flowai_sdk.utils import FieldMetadata, PathParamMetadata, QueryParamMetadata
from typing import Any
from typing_extensions import Annotated, TypedDict


class DeleteValidationValidationsValidationIDDeleteRequestTypedDict(TypedDict):
    validation_id: str
    current_user_payload: Any


class DeleteValidationValidationsValidationIDDeleteRequest(BaseModel):
    validation_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    current_user_payload: Annotated[
        Any, FieldMetadata(query=QueryParamMetadata(style="form", explode=True))
    ]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flowai_sdk.types import BaseModel
from typing_extensions import TypedDict


class JWTTokenTypedDict(TypedDict):
    jwt: str


class JWTToken(BaseModel):
    jwt: str



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flowai_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from flowai_sdk.utils import FieldMetadata, QueryParamMetadata
from pydantic import model_serializer
from typing import Any, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class ListValidationsValidationsGetRequestTypedDict(TypedDict):
    current_user_payload: Any
    skip: NotRequired[int]
    limit: NotRequired[int]
    sort_by: NotRequired[Nullable[str]]
    r"""Field to sort by"""
    sort_order: NotRequired[str]
    r"""Sort direction (asc or desc)"""
    test_case_id: NotRequired[Nullable[str]]
    r"""Filter by test case ID"""
    validator_id: NotRequired[Nullable[str]]
    r"""Filter by validator user ID"""
    is_accepted: NotRequired[Nullable[bool]]
    r"""Filter by acceptance status"""
    created_after: NotRequired[Nullable[str]]
    r"""Filter by creation date (ISO format)"""
    created_before: NotRequired[Nullable[str]]
    r"""Filter by creation date (ISO format)"""


class ListValidationsValidationsGetRequest(BaseModel):
    current_user_payload: Annotated[
        Any, FieldMetadata(query=QueryParamMetadata(style="form", explode=True))
    ]

    skip: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = 0

    limit: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = 100

    sort_by: Annotated[
        OptionalNullable[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET
    r"""Field to sort by"""

    sort_order: Annotated[
        Optional[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = "asc"
    r"""Sort direction (asc or desc)"""

    test_case_id: Annotated[
        OptionalNullable[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET
    r"""Filter by test case ID"""

    validator_id: Annotated[
        OptionalNullable[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET
    r"""Filter by validator user ID"""

    is_accepted: Annotated[
        OptionalNullable[bool],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET
    r"""Filter by acceptance status"""

    created_after: Annotated[
        OptionalNullable[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET
    r"""Filter by creation date (ISO format)"""

    created_before: Annotated[
        OptionalNullable[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET
    r"""Filter by creation date (ISO format)"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "skip",
            "limit",
            "sort_by",
            "sort_order",
            "test_case_id",
            "validator_id",
            "is_accepted",
            "created_after",
            "created_before",
        ]
        nullable_fields = [
            "sort_by",
            "test_case_id",
            "validator_id",
            "is_accepted",
            "created_after",
            "created_before",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from flowai_sdk.types import BaseModel
from typing_extensions import TypedDict


class ValidationItemFeedbackTypedDict(TypedDict):
    r"""Schema for reading/returning validation item feedback"""

    trajectory_item_id: str
    feedback_text: str
    id: str
    test_case_validation_id: str
    created_at: datetime
    updated_at: datetime


class ValidationItemFeedback(BaseModel):
    r"""Schema for reading/returning validation item feedback"""

    trajectory_item_id: str

    feedback_text: str

    id: str

    test_case_validation_id: str

    created_at: datetime

    updated_at: datetime



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .projectupdate import ProjectUpdate, ProjectUpdateTypedDict
from flowai_sdk.types import BaseModel
from flowai_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class UpdateProjectProjectsProjectIDPatchRequestTypedDict(TypedDict):
    project_id: str
    project_update: ProjectUpdateTypedDict


class UpdateProjectProjectsProjectIDPatchRequest(BaseModel):
    project_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    project_update: Annotated[
        ProjectUpdate,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .testcasecreate import TestCaseCreate, TestCaseCreateTypedDict
from flowai_sdk.types import BaseModel
from flowai_sdk.utils import FieldMetadata, QueryParamMetadata, RequestMetadata
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class CreateTestCaseTestCasesPostRequestTypedDict(TypedDict):
    test_case_create: TestCaseCreateTypedDict
    api_key_user_id: NotRequired[str]


class CreateTestCaseTestCasesPostRequest(BaseModel):
    test_case_create: Annotated[
        TestCaseCreate,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]

    api_key_user_id: Annotated[
        Optional[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = "mock_api_key_user_id"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .stageupdatepayload import StageUpdatePayload, StageUpdatePayloadTypedDict
from flowai_sdk.types import BaseModel
from flowai_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class UpdateStageStagesStageIDPutRequestTypedDict(TypedDict):
    stage_id: int
    stage_update_payload: StageUpdatePayloadTypedDict


class UpdateStageStagesStageIDPutRequest(BaseModel):
    stage_id: Annotated[
        int, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    stage_update_payload: Annotated[
        StageUpdatePayload,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flowai_sdk.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class ValidatorCompleteSignupRequestTypedDict(TypedDict):
    validation_task_id: str
    validator_id: str
    unique_url_key: str


class ValidatorCompleteSignupRequest(BaseModel):
    validation_task_id: Annotated[str, pydantic.Field(alias="validationTaskId")]

    validator_id: Annotated[str, pydantic.Field(alias="validatorId")]

    unique_url_key: Annotated[str, pydantic.Field(alias="uniqueUrlKey")]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flowai_sdk.types import BaseModel
from flowai_sdk.utils import FieldMetadata, HeaderMetadata
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class HandleClerkWebhookEndpointClerkWebhooksPostRequestTypedDict(TypedDict):
    svix_id: NotRequired[str]
    svix_timestamp: NotRequired[str]
    svix_signature: NotRequired[str]


class HandleClerkWebhookEndpointClerkWebhooksPostRequest(BaseModel):
    svix_id: Annotated[
        Optional[str],
        pydantic.Field(alias="svix-id"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = None

    svix_timestamp: Annotated[
        Optional[str],
        pydantic.Field(alias="svix-timestamp"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = None

    svix_signature: Annotated[
        Optional[str],
        pydantic.Field(alias="svix-signature"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class StageFileTypeEnum(str, Enum):
    AGENT_RULES = "agent_rules"
    TOOL_DEFINITIONS = "tool_definitions"
    DATABASE_SCHEMA_RULES = "database_schema_rules"
    CUSTOM_DATA_FILES = "custom_data_files"
    RELATIONAL_DB_SCHEMA = "relational_db_schema"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .testcasevalidationcreate import (
    TestCaseValidationCreate,
    TestCaseValidationCreateTypedDict,
)
from flowai_sdk.types import BaseModel
from flowai_sdk.utils import FieldMetadata, QueryParamMetadata, RequestMetadata
from typing import Any
from typing_extensions import Annotated, TypedDict


class CreateTestCaseValidationValidationsPostRequestTypedDict(TypedDict):
    current_user_payload: Any
    test_case_validation_create: TestCaseValidationCreateTypedDict


class CreateTestCaseValidationValidationsPostRequest(BaseModel):
    current_user_payload: Annotated[
        Any, FieldMetadata(query=QueryParamMetadata(style="form", explode=True))
    ]

    test_case_validation_create: Annotated[
        TestCaseValidationCreate,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .validatorurlinfo import ValidatorURLInfo, ValidatorURLInfoTypedDict
from datetime import datetime
from flowai_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class CreateValidationTaskResponseTypedDict(TypedDict):
    r"""Response schema for creating a validation task for a batch."""

    validation_task_id: str
    batch_id: str
    status: str
    created_at: datetime
    validator_urls: List[ValidatorURLInfoTypedDict]


class CreateValidationTaskResponse(BaseModel):
    r"""Response schema for creating a validation task for a batch."""

    validation_task_id: str

    batch_id: str

    status: str

    created_at: datetime

    validator_urls: List[ValidatorURLInfo]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from flowai_sdk.types import BaseModel
from typing import Any, Dict
from typing_extensions import TypedDict


class DatasetItemReadTypedDict(TypedDict):
    dataset_id: str
    item_data: Dict[str, Any]
    id: str
    created_at: datetime
    updated_at: datetime


class DatasetItemRead(BaseModel):
    dataset_id: str

    item_data: Dict[str, Any]

    id: str

    created_at: datetime

    updated_at: datetime



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flowai_sdk.types import BaseModel
from typing_extensions import TypedDict


class ValidatorURLInfoTypedDict(TypedDict):
    r"""Information about a validator's access URL for a validation task."""

    validator_id: str
    clerk_user_id: str
    url: str


class ValidatorURLInfo(BaseModel):
    r"""Information about a validator's access URL for a validation task."""

    validator_id: str

    clerk_user_id: str

    url: str



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flowai_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from flowai_sdk.utils import validate_const
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import Any, Literal, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class ToolCallStepCreateTypedDict(TypedDict):
    r"""Schema for creating a tool call step."""

    order: int
    tool_name: str
    type: Literal["tool_call"]
    arguments: NotRequired[Nullable[Any]]
    output: NotRequired[Nullable[Any]]


class ToolCallStepCreate(BaseModel):
    r"""Schema for creating a tool call step."""

    order: int

    tool_name: str

    TYPE: Annotated[
        Annotated[
            Optional[Literal["tool_call"]], AfterValidator(validate_const("tool_call"))
        ],
        pydantic.Field(alias="type"),
    ] = "tool_call"

    arguments: OptionalNullable[Any] = UNSET

    output: OptionalNullable[Any] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["type", "arguments", "output"]
        nullable_fields = ["arguments", "output"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum
from flowai_sdk.types import BaseModel
from typing_extensions import TypedDict


class Role(str, Enum):
    USER = "user"
    VALIDATOR = "validator"


class UserRoleUpdateTypedDict(TypedDict):
    r"""Schema for updating a user's role in Clerk."""

    role: Role


class UserRoleUpdate(BaseModel):
    r"""Schema for updating a user's role in Clerk."""

    role: Role
